framework

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 15, 2026 License: GPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type About

type About interface {
	ShowVersion()
	ShowHelp()
}

type AppInfo

type AppInfo interface {
	ShowVersion()
	ShowAbout()
}

type Application

type Application interface {

	// implement to provide a running application.
	Run()

	// GetName returns the name of the application.  Used by the
	// version service
	GetName() string
}

interface describing an application

type Logger

type Logger interface {

	// Implement to log an error and then call panic
	Panic(...any)

	// Implement to print all messages sent to it
	Println(...any)

	// Implement to print all messages sent to it
	Print(...any)

	// Implement to print all messages with an Emergancy category
	PrintEmergancy(...any)

	// Implement to print all message with an Alert category
	PrintAlert(...any)

	// Implement to print all messages with a Critical category
	PrintCritical(...any)

	// Implement to print all messages with an Error category
	PrintError(...any)

	// Implement to print all messages with a Warning category
	PrintWarning(...any)

	// Implement to print all messages with a Notice category
	PrintNotice(...any)

	// Implement to print all messages with an Info category
	PrintInfo(...any)

	// Implement to print all messages with a Debug category
	PrintDebug(...any)
}

Logger is the basis of any loggers that are used in goxhkd and related programs

type SystemInterrupt

type SystemInterrupt interface {
	Start(context.CancelFunc)
}

type VersionService

type VersionService interface {

	// ShowVersion should be implemented to display the version of
	// the app.  Then it should terminate the program.
	ShowVersion()
}

The interface for the version service. The intended usage is to display the applications version and then terminate.

type Worker

type Worker interface {
	Start(wg *sync.WaitGroup, ctx context.Context)
}

Jump to